==> jc-1.4.0.tar.gz: java/io/BufferedOutputStream.h <==
// public class java.io.BufferedOutputStream

// class file dependencies
// @dep_class 3a02e95b01d65f2b java_io_BufferedOutputStream
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterOutputStream

#include "java/io/FilterOutputStream.h"

#ifndef _JC_java_io_BufferedOutputStream_H_
#define _JC_java_io_BufferedOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_BufferedOutputStream$sub_refs	_jc_java_io_BufferedOutputStream$sub_refs;
typedef struct _jc_java_io_BufferedOutputStream$sub_nonrefs	_jc_java_io_BufferedOutputStream$sub_nonrefs;
typedef struct _jc_java_io_BufferedOutputStream$refs	_jc_java_io_BufferedOutputStream$refs;
typedef struct _jc_java_io_BufferedOutputStream$nonrefs	_jc_java_io_BufferedOutputStream$nonrefs;
typedef struct _jc_java_io_BufferedOutputStream$object	_jc_java_io_BufferedOutputStream$object;

typedef struct _jc_java_io_BufferedOutputStream$fields_struct	_jc_java_io_BufferedOutputStream$fields_struct;
typedef const struct _jc_java_io_BufferedOutputStream$vmethods	_jc_java_io_BufferedOutputStream$vmethods;
typedef const struct _jc_java_io_BufferedOutputStream$vtable	_jc_java_io_BufferedOutputStream$vtable;
typedef const struct _jc_java_io_BufferedOutputStream$vtype	_jc_java_io_BufferedOutputStream$vtype;

// Class fields structure
struct _jc_java_io_BufferedOutputStream$fields_struct {
	jint	DEFAULT__5fBUFFER__5fSIZE;
};
extern _jc_java_io_BufferedOutputStream$fields_struct _jc_java_io_BufferedOutputStream$class_fields;

// Constructors
extern void _jc_java_io_BufferedOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_java_io_BufferedOutputStream$object *, struct _jc_java_io_OutputStream$object *);
extern void _jc_java_io_BufferedOutputStream$method$_init$782fe41f0aefd897(_jc_env *, struct _jc_java_io_BufferedOutputStream$object *, struct _jc_java_io_OutputStream$object *, jint);

// Virtual methods
extern void _jc_java_io_BufferedOutputStream$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_java_io_BufferedOutputStream$object *);
extern void _jc_java_io_BufferedOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_io_BufferedOutputStream$object *, jint);
extern void _jc_java_io_BufferedOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_io_BufferedOutputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_io_BufferedOutputStream$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_java_io_BufferedOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_io_BufferedOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_java_io_BufferedOutputStream$vmethods {
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_java_io_BufferedOutputStream$object *);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_io_BufferedOutputStream$object *, jint);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_io_BufferedOutputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_java_io_BufferedOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_java_io_BufferedOutputStream$vmethods	java_io_BufferedOutputStream;
};

// Vtype
struct _jc_java_io_BufferedOutputStream$vtype {
	_jc_type			type;
	_jc_java_io_BufferedOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_BufferedOutputStream$sub_refs {
	_jc_byte_array	*buf;
};

// Reference instance fields (object)
struct _jc_java_io_BufferedOutputStream$refs {
    _jc_java_io_BufferedOutputStream$sub_refs	java_io_BufferedOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_BufferedOutputStream$sub_nonrefs {
	jint	count;
};

// Non-reference instance fields (object)
struct _jc_java_io_BufferedOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_java_io_BufferedOutputStream$sub_nonrefs	java_io_BufferedOutputStream;
};

// Object instance structure
struct _jc_java_io_BufferedOutputStream$object {
	_jc_java_io_BufferedOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_BufferedOutputStream$vtype	*vtype;
	_jc_java_io_BufferedOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_BufferedOutputStream$vtype _jc_java_io_BufferedOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_BufferedOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_BufferedOutputStream$class_object;

#endif	/* _JC_java_io_BufferedOutputStream_H_ */

==> jc-1.4.6.tar.gz: java/io/BufferedOutputStream.h <==
// public class java.io.BufferedOutputStream

// class file dependencies
// @dep_class 3a02e95b01d65f2b java_io_BufferedOutputStream
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterOutputStream

#include "java/io/FilterOutputStream.h"

#ifndef _JC_java_io_BufferedOutputStream_H_
#define _JC_java_io_BufferedOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_BufferedOutputStream$sub_refs	_jc_java_io_BufferedOutputStream$sub_refs;
typedef struct _jc_java_io_BufferedOutputStream$sub_nonrefs	_jc_java_io_BufferedOutputStream$sub_nonrefs;
typedef struct _jc_java_io_BufferedOutputStream$refs	_jc_java_io_BufferedOutputStream$refs;
typedef struct _jc_java_io_BufferedOutputStream$nonrefs	_jc_java_io_BufferedOutputStream$nonrefs;
typedef struct _jc_java_io_BufferedOutputStream$object	_jc_java_io_BufferedOutputStream$object;

typedef struct _jc_java_io_BufferedOutputStream$fields_struct	_jc_java_io_BufferedOutputStream$fields_struct;
typedef const struct _jc_java_io_BufferedOutputStream$vmethods	_jc_java_io_BufferedOutputStream$vmethods;
typedef const struct _jc_java_io_BufferedOutputStream$vtable	_jc_java_io_BufferedOutputStream$vtable;
typedef const struct _jc_java_io_BufferedOutputStream$vtype	_jc_java_io_BufferedOutputStream$vtype;

// Class fields structure
struct _jc_java_io_BufferedOutputStream$fields_struct {
	jint	DEFAULT__5fBUFFER__5fSIZE;
};
extern _jc_java_io_BufferedOutputStream$fields_struct _jc_java_io_BufferedOutputStream$class_fields;

// Constructors
extern void _jc_java_io_BufferedOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_java_io_BufferedOutputStream$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_BufferedOutputStream$method$_init$782fe41f0aefd897(_jc_env *, struct _jc_java_io_BufferedOutputStream$object *, struct _jc_java_io_OutputStream$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_io_BufferedOutputStream$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_java_io_BufferedOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_BufferedOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_io_BufferedOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_io_BufferedOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_io_BufferedOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_BufferedOutputStream$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_java_io_BufferedOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_io_BufferedOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_java_io_BufferedOutputStream$vmethods {
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_java_io_BufferedOutputStream$object *) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_io_BufferedOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_io_BufferedOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_BufferedOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_java_io_BufferedOutputStream$vmethods	java_io_BufferedOutputStream;
};

// Vtype
struct _jc_java_io_BufferedOutputStream$vtype {
	_jc_type			type;
	_jc_java_io_BufferedOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_BufferedOutputStream$sub_refs {
	_jc_byte_array	*buf;
};

// Reference instance fields (object)
struct _jc_java_io_BufferedOutputStream$refs {
    _jc_java_io_BufferedOutputStream$sub_refs	java_io_BufferedOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_BufferedOutputStream$sub_nonrefs {
	jint	count;
};

// Non-reference instance fields (object)
struct _jc_java_io_BufferedOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_java_io_BufferedOutputStream$sub_nonrefs	java_io_BufferedOutputStream;
};

// Object instance structure
struct _jc_java_io_BufferedOutputStream$object {
	_jc_java_io_BufferedOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_BufferedOutputStream$vtype	*vtype;
	_jc_java_io_BufferedOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_BufferedOutputStream$vtype _jc_java_io_BufferedOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_BufferedOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_BufferedOutputStream$class_object;

#endif	/* _JC_java_io_BufferedOutputStream_H_ */
